Struct amazon_sp_aplus_content::models::validate_content_document_asin_relations_response::ValidateContentDocumentAsinRelationsResponse
source · [−]pub struct ValidateContentDocumentAsinRelationsResponse {
pub warnings: Option<Vec<Error>>,
pub errors: Vec<Error>,
}Fields
warnings: Option<Vec<Error>>A set of messages to the user, such as warnings or comments.
errors: Vec<Error>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl ValidateContentDocumentAsinRelationsResponse
impl ValidateContentDocumentAsinRelationsResponse
pub fn new(errors: Vec<Error>) -> ValidateContentDocumentAsinRelationsResponse